@@ -5,6 +5,7 @@ import xml.etree.ElementTree as ET
 
 # 3rd Party Imports
 import requests
+import dicttoxml
 
 TOKEN = os.getenv('PIVOTAL_TOKEN', None)
 
@@ -183,6 +184,11 @@ class Project(object):
             root = ET.fromstring(resposne.text)
             return Story.from_node(root)
 
+    def create_story(self,story_dict):
+        stories_url = "http://www.pivotaltracker.com/services/v3/projects/{}/stories".format(self.project_id)
+        story_xml = dicttoxml.dicttoxml(story_dict, root=False)
+        _perform_pivotal_post(stories_url, story_xml)
+
     def unestimated_stories(self):
         stories = self.get_stories('type:feature state:unstarted')
         return [story for story in stories if int(story.estimate) == -1]
@@ -213,6 +219,12 @@ def _perform_pivotal_put(url):
     response.raise_for_status()
     return response
 
+def _perform_pivotal_post(url,payload_xml):
+    headers = {'X-TrackerToken': TOKEN, 'Content-type': "application/xml"}
+    response = requests.post(url, data=payload_xml, headers=headers)
+    response.raise_for_status()
+    return response
+
 
 def _parse_text(node, key):
     """parses test from an ElementTree node, if not found returns empty string"""
